@@ -9,7 +9,7 @@ from . import redis_handle
 class BaseModel(PyDanticBaseModel):
     def to_file(self, path):
         with open(path, 'w') as f:
-            json.dump(json.loads(self.json()), f)
+            json.dump(self.to_dict(), f)
 
     def save(self):
         dbo = DB(redis_handle(), model=self)
